Package: fastDummies
Type: Package
Title: Fast Creation of Dummy (Binary) Columns and Rows from
        Categorical Variables
Version: 1.7.6
Authors@R: c(
    person("Jacob", "Kaplan", email = "jkkaplan6@gmail.com", role = c("aut", "cre"),
    comment = c(ORCID = "0000-0002-0601-0387")), 
    person("Benjamin", "Schlegel", email = "kontakt@benjaminschlegl.ch", role =  "ctb"))
Description: Creates dummy columns from columns that have categorical variables (character or factor types). You can also specify which columns to make dummies out of, or which columns to ignore. Also creates dummy rows from character, factor, and Date columns. This package provides a significant speed increase from creating dummy variables through model.matrix().
Depends: R (>= 2.10)
Imports: data.table, tibble, stringr
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/jacobkap/fastDummies,
        https://jacobkap.github.io/fastDummies/
BugReports: https://github.com/jacobkap/fastDummies/issues
RoxygenNote: 7.3.2
Suggests: testthat (>= 2.1.0), knitr, rmarkdown, covr, spelling, dplyr
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2026-04-22 15:26:34 UTC; jkkap
Author: Jacob Kaplan [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0601-0387>),
  Benjamin Schlegel [ctb]
Maintainer: Jacob Kaplan <jkkaplan6@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 16:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 05:31:47 UTC; unix
